(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     28336,        877]*)
(*NotebookOutlinePosition[     29310,        911]*)
(*  CellTagsIndexPosition[     29222,        905]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["   RestartingNDSolve", "Subtitle",
  CellMargins->{{0, 0}, {11.5, 0}},
  CellFrameMargins->{{8, 0}, {18, 18}},
  Background->RGBColor[0.74902, 0.694118, 0.552941]],

Cell[TextData[{
  "This notebook appears as an article in ",
  StyleBox[ButtonBox["Mathematica in Education and Research",
    ButtonData:>{
      URL[ "http://www.ijournals.net"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  ButtonBox[", vol. 10, no. 1",
    ButtonData:>{
      URL[ "http://www.ijournals.net"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellMargins->{{Inherited, Inherited}, {8.625, 0}}],

Cell[CellGroupData[{

Cell["Author Info", "SubsubsectionIcon"],

Cell[TextData[{
  "By Selwyn Hollis \nDecember 2004\n",
  ButtonBox["http://www.appliedsymbols.com",
    ButtonData:>{
      URL[ "http://www.appliedsymbols.com"], None},
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["shollis@appliedsymbols.com",
    ButtonData:>{
      URL[ "mailto:shollis.appliedsymbols.com"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Description", "SubsectionIcon"],

Cell[TextData[{
  "This package defines a function named ",
  StyleBox["RestartingNDSolve",
    FontFamily->"Courier"],
  ", which automates the process of restarting ",
  StyleBox["NDSolve",
    FontFamily->"Courier"],
  " when a given condition on the solution is satisfied. This function was \
originally written for the purpose of solving a system of differential \
equations that arises from a model of the budding yeast cell cycle, which is \
presented below as an example."
}], "Text"],

Cell[TextData[{
  "(",
  StyleBox["Note",
    FontSlant->"Italic"],
  ": This work was done prior to the release of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 5.1, in which the functionality provided by ",
  StyleBox["RestartingNDSolve",
    FontFamily->"Courier"],
  " can be achieved differently by using the ",
  StyleBox["EventLocator",
    FontFamily->"Courier"],
  " controller method of ",
  StyleBox["NDSolve",
    FontFamily->"Courier"],
  ".)"
}], "Text"],

Cell[TextData[{
  StyleBox["RestartingNDSolve",
    FontFamily->"Courier"],
  " is based on ",
  StyleBox["NDSolve",
    FontFamily->"Courier"],
  ", making use of the ",
  StyleBox["StoppingTest",
    FontFamily->"Courier"],
  " option. While no mention is made of ",
  StyleBox["StoppingTest",
    FontFamily->"Courier"],
  " in the Help Browser description of ",
  StyleBox["NDSolve",
    FontFamily->"Courier"],
  ", one can find a description of it at ",
  ButtonBox["http://support.wolfram.com/mathematica/kernel/Symbols",
    ButtonData:>{
      URL[ "http://support.wolfram.com/mathematica/kernel/Symbols"], None},
    ButtonStyle->"Hyperlink"],
  " and get information on it as follows:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?StoppingTest\)\)], "Input",
  CellFrame->{{2, 0}, {0, 0.25}},
  CellFrameMargins->8,
  CellFrameColor->RGBColor[0.592157, 0.313726, 0.313726],
  CellFrameLabels->{{Inherited, Inherited}, {None, Inherited}},
  Background->RGBColor[1, 1, 0.840558]],

Cell[BoxData[
    \("StoppingTest is an option for NDSolve that can be used to stop the \
integration of the ode when a certain condition is found to be True. The \
condition can evaluate to True/False only and should contain the dependent \
and independent variables explicitly. This option cannot be used for linear \
boundary value problems."\)], "Print",
  FontSize->10,
  CellTags->"Info3305099142-2784705"]
}, Open  ]],

Cell[TextData[{
  "Basic usage of ",
  StyleBox["RestartingNDSolve",
    FontFamily->"Courier"],
  " is as follows:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"RestartingNDSolve", "[", 
        RowBox[{
          StyleBox["sys",
            FontFamily->"Times",
            FontSlant->"Italic"], ",", 
          StyleBox["vars",
            FontFamily->"Times",
            FontSlant->"Italic"], ",", 
          RowBox[{"{", 
            RowBox[{
              StyleBox["t",
                FontFamily->"Times",
                FontSlant->"Italic"], ",", 
              StyleBox[
                SubscriptBox[
                  StyleBox["t",
                    FontSlant->"Italic"], "0"],
                FontFamily->"Times"], ",", 
              SubscriptBox[
                StyleBox["t",
                  FontFamily->"Times",
                  FontSlant->"Italic"], "max"]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              StyleBox["restartcond",
                FontFamily->"Times",
                FontSlant->"Italic"], ",", 
              StyleBox["restartfunc",
                FontFamily->"Times",
                FontSlant->"Italic"]}], "}"}]}], "]"}], 
      " "}]], "DefinitionBox"],

Cell[TextData[{
  "In a nutshell, this is what ",
  StyleBox["RestartingNDSolve",
    FontFamily->"Courier"],
  " does:"
}], "Text"],

Cell[TextData[{
  "\tWhile ",
  Cell[BoxData[
      \(TraditionalForm\`t < t\_max\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t\[Bullet] start ",
  StyleBox["NDSolve",
    FontFamily->"Courier"],
  " with given starting values"
}], "Text"],

Cell[TextData[{
  "\t\t\[Bullet] stop ",
  StyleBox["NDSolve",
    FontFamily->"Courier"],
  " when ",
  StyleBox["restartcond",
    FontSlant->"Italic"],
  " becomes ",
  StyleBox["True",
    FontFamily->"Courier"]
}], "Text"],

Cell["\t\t\[Bullet] correct overshoot", "Text"],

Cell[TextData[{
  "\t\t\[Bullet] apply ",
  StyleBox["restartfunc",
    FontSlant->"Italic"],
  " to final values to obtain new starting values\n"
}], "Text"],

Cell[CellGroupData[{

Cell["Overshoot Correction", "SubsubsectionIcon"],

Cell[TextData[{
  "When the restart condition is met and ",
  StyleBox["NDSolve",
    FontFamily->"Courier"],
  " stops, the current time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_c\)]],
  " is almost always greater than the correct restart time and may be in \
error by any amount less than the current time-step ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[VeryThinSpace]t\_c\)]],
  ", which is sometimes large. Overshoot could be controlled by means of the \
",
  StyleBox["MaxStepSize",
    FontFamily->"Courier"],
  " option, but doing so causes a drastic decrease in speed. Instead we ",
  StyleBox["correct",
    FontSlant->"Italic"],
  " the overshoot by iteratively re-solving between the previous time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_c - \[CapitalDelta]\[VeryThinSpace]t\_c\)]],
  " and the current time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_c\)]],
  ". Current times and time-steps are extracted from ",
  StyleBox["NDSolve`StateData",
    FontFamily->"Courier"],
  " objects. (These are described in the ",
  ButtonBox["Advanced Documentation for ",
    ButtonData:>"Advanced Documentation: NDSolve",
    ButtonStyle->"RefGuideLinkText"],
  Cell[BoxData[
      StyleBox[
        ButtonBox["NDSolve",
          ButtonData:>"Advanced Documentation: NDSolve",
          ButtonStyle->"RefGuideLinkText"],
        FontFamily->"Courier"]]],
  ".) "
}], "Text"],

Cell["\<\
The stopping criterion for overshoot correction may be controlled \
with the following option:\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox["option",
              FontSlant->"Italic"], 
            StyleBox["default",
              FontSlant->"Italic"], " "},
          {
            StyleBox[
              FormBox[
                StyleBox["TimePrecisionGoal",
                  FontFamily->"Courier"],
                "TraditionalForm"],
              FontFamily->"Courier"], 
            StyleBox[
              FormBox[
                FormBox[
                  StyleBox["8",
                    FontFamily->"Courier"],
                  "TraditionalForm"],
                "TraditionalForm"],
              FontFamily->"Courier"], 
            
            StyleBox[\(the\ effective\ digits\ of\ precision\ sought\ by\ \
overshoot\ correction\),
              LineSpacing->{1, 1}]}
          }], TraditionalForm]]]], "DefinitionBox3Col",
  GridBoxOptions->{RowLines->{0.5, False}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Other Options", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox["option",
              FontSlant->"Italic"], 
            StyleBox["default",
              FontSlant->"Italic"], " "},
          {
            StyleBox[
              FormBox[
                StyleBox["MinRecoveryTime",
                  FontFamily->"Courier"],
                "TraditionalForm"],
              FontFamily->"Courier"], 
            StyleBox[\(1/10\),
              FontFamily->"Courier"], \(minimum\ time\ between\ restarts\)},
          {
            StyleBox[
              FormBox[
                StyleBox["Reporting",
                  FontFamily->"Courier"],
                "TraditionalForm"],
              FontFamily->"Courier"], 
            StyleBox[
              FormBox[
                StyleBox["False",
                  FontFamily->"Courier"],
                "TraditionalForm"],
              FontFamily->"Courier"], \(whether\ to\ print\ restart\ times\)}
          }], TraditionalForm]]]], "DefinitionBox3Col",
  GridBoxOptions->{RowLines->{0.5, False}}],

Cell[TextData[{
  "The ",
  StyleBox["MinRecoveryTime",
    FontFamily->"Courier"],
  " option is needed to prevent immediate restarts, since the restart \
condition may still be satisfied for some time after restarting. In general, \
an appropriate setting for ",
  StyleBox["MinRecoveryTime",
    FontFamily->"Courier"],
  " is problem dependent. A warning message is invoked if the time between \
consecutive restart times is close to the ",
  StyleBox["MinRecoveryTime",
    FontFamily->"Courier"],
  " value. If this message appears, one should increase the setting of ",
  StyleBox["MinRecoveryTime",
    FontFamily->"Courier"],
  "."
}], "Text"],

Cell[TextData[{
  "The ",
  StyleBox["Reporting",
    FontFamily->"Courier"],
  " option is provided to allow or suppress printing of the restart times as \
they occur during the computation."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Output", "SubsubsectionIcon"],

Cell[TextData[{
  "The output of ",
  StyleBox["RestartingNDSolve",
    FontFamily->"Courier"],
  " is a list of functions of the form"
}], "Text"],

Cell[BoxData[
    RowBox[{"Which", "[", 
      RowBox[{
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox["t",
                FontFamily->"Times",
                FontSlant->"Italic"], "0"],
            ScriptLevel->1,
            FontFamily->"Times"], "\[LessEqual]", 
          StyleBox["t",
            FontFamily->"Times",
            FontSlant->"Italic"], "<", 
          StyleBox[
            SubscriptBox[
              StyleBox["t",
                FontFamily->"Times",
                FontSlant->"Italic"], "1"],
            ScriptLevel->1,
            FontFamily->"Times"]}], ",", 
        RowBox[{
          RowBox[{"InterpolatingFunction", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"{", 
                  RowBox[{
                    StyleBox[
                      SubscriptBox[
                        StyleBox["t",
                          FontSlant->"Italic"], "0"],
                      ScriptLevel->1,
                      FontFamily->"Times"], ",", 
                    StyleBox[
                      SubscriptBox[
                        StyleBox[
                          OverscriptBox[
                            StyleBox["t",
                              FontFamily->"Times",
                              FontSlant->"Italic"], "^"],
                          FontFamily->"Times",
                          FontSlant->"Italic"], "1"],
                      ScriptLevel->1,
                      FontFamily->"Times"]}], "}"}], "}"}], ",", "<>"}], 
            "]"}], "[", 
          StyleBox["t",
            FontFamily->"Times",
            FontSlant->"Italic"], "]"}], ",", " ", 
        StyleBox["\[Ellipsis]",
          FontFamily->"Helvetica"], 
        StyleBox[" ",
          FontFamily->"Times"], ",", 
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox["t",
                ScriptLevel->1,
                FontFamily->"Times",
                FontSlant->"Italic"], 
              StyleBox["n",
                FontSlant->"Italic"]],
            ScriptLevel->1,
            FontFamily->"Times"], "\[LessEqual]", 
          StyleBox["t",
            FontFamily->"Times",
            FontSlant->"Italic"], "<", 
          SubscriptBox[
            StyleBox["t",
              FontFamily->"Times",
              FontSlant->"Italic"], "max"]}], ",", 
        RowBox[{
          RowBox[{"InterpolatingFunction", "[", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{"{", 
                  RowBox[{
                    StyleBox[
                      SubscriptBox[
                        StyleBox["t",
                          ScriptLevel->1,
                          FontFamily->"Times",
                          FontSlant->"Italic"], 
                        StyleBox["n",
                          FontSlant->"Italic"]],
                      ScriptLevel->1,
                      FontFamily->"Times"], ",", 
                    SubscriptBox[
                      StyleBox["t",
                        FontFamily->"Times",
                        FontSlant->"Italic"], 
                      StyleBox["max",
                        FontFamily->"Times"]]}], "}"}], "}"}], ",", "<>"}], 
            "]"}], "[", 
          StyleBox["t",
            FontFamily->"Times",
            FontSlant->"Italic"], "]"}]}], 
      StyleBox["\[NonBreakingSpace]",
        FontFamily->"Times"], "]"}]], "Program",
  Evaluatable->False,
  ScriptSizeMultipliers->0.71,
  ScriptMinSize->5,
  FontWeight->"Plain"],

Cell[TextData[{
  "Here ",
  Cell[BoxData[
      \(TraditionalForm\`t\_1, \[Ellipsis], t\_n\)]],
  " are the corrected restart times, and  ",
  Cell[BoxData[
      \(TraditionalForm\`\(t\&^\)\_1, \[Ellipsis], \(t\&^\)\_n\)]],
  " are the uncorrected restart times."
}], "Text",
  ScriptSizeMultipliers->0.71]
}, Open  ]],

Cell[CellGroupData[{

Cell["Loading The Package", "SubsubsectionIcon"],

Cell[BoxData[
    \(Needs["\<RNDS`RestartingNDSolve`\>"]\)], "Input",
  CellFrame->{{2, 0}, {0, 0.25}},
  InitializationCell->True,
  CellFrameMargins->8,
  CellFrameColor->RGBColor[0.592157, 0.313726, 0.313726],
  CellFrameLabels->{{Inherited, Inherited}, {None, Inherited}},
  Background->RGBColor[1, 1, 0.840558]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["A Simple Example", "SubsectionIcon"],

Cell[TextData[{
  "Consider the following toy system, which is constructed so that its \
solution (without restarts) is ",
  Cell[BoxData[
      \(TraditionalForm\`\((x(t), 
          y(t))\) = \((\[ExponentialE]\^t, \[ExponentialE]\^\(-t\))\)\)]],
  "."
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"sys1", ":=", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "(", "t", ")"}], 
              "\[Equal]", \(1\/\(y(t)\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "(", "t", ")"}], 
              "\[Equal]", \(-\(1\/\(x(t)\)\)\)}], ",", \(x(0) \[Equal] 1\), 
            ",", \(y(0) \[Equal] 1\)}], "}"}]}], TraditionalForm]], "Input",
  CellFrame->{{2, 0}, {0, 0.25}},
  InitializationCell->True,
  CellFrameMargins->8,
  CellFrameColor->RGBColor[0.592157, 0.313726, 0.313726],
  CellFrameLabels->{{Inherited, Inherited}, {None, Inherited}},
  FormatType->StandardForm,
  Background->RGBColor[1, 1, 0.840558]],

Cell[TextData[{
  "With the following restart condition and restart function, the exact \
restart times will be ",
  Cell[BoxData[
      \(TraditionalForm\`1, 2, 3, \[Ellipsis]\)]],
  ", corresponding to the discontinuities of the solution ",
  Cell[BoxData[
      \(TraditionalForm\`\((x(t), 
          y(t))\) = \((\[ExponentialE]\^\(\(\ \)\(t - \[LeftFloor]t\
\[RightFloor]\)\), \[ExponentialE]\^\(\(\[ThinSpace]\)\(\[LeftFloor]t\
\[RightFloor] - t\)\))\)\)]],
  "."
}], "Text"],

Cell[BoxData[{
    FormBox[\(restartcond := 
        x(t) + y(t) \[GreaterEqual] \[ExponentialE] + 1/\[ExponentialE]\), 
      TraditionalForm], "\n", 
    FormBox[
      RowBox[{
        RowBox[{"restartfn", "[", 
          RowBox[{"{", 
            RowBox[{
              StyleBox[
                RowBox[{
                  StyleBox["x",
                    FontSlant->"Italic"], "_"}]], ",", 
              StyleBox[
                RowBox[{
                  StyleBox["y",
                    FontSlant->"Italic"], "_"}]]}], "}"}], "]"}], 
        ":=", \({\ x/\[ExponentialE], \[ExponentialE]\ y}\)}], 
      TraditionalForm]}], "Input",
  CellFrame->{{2, 0}, {0, 0.25}},
  InitializationCell->True,
  CellFrameMargins->8,
  CellFrameColor->RGBColor[0.592157, 0.313726, 0.313726],
  CellFrameLabels->{{Inherited, Inherited}, {None, Inherited}},
  Background->RGBColor[1, 1, 0.840558]],

Cell[TextData[{
  "The following compute and then plot the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] t \[LessEqual] 4\)]],
  ":"
}], "Text"],

Cell[BoxData[{
    \(TraditionalForm\`\(tmax = 4;\)\), "\n", 
    \(TraditionalForm\`result = 
      RestartingNDSolve[\ 
        sys1, {x, y}, {t, 0, tmax}, {restartcond, restartfn}, 
        Reporting \[Rule] True]\)}], "Input",
  CellFrame->{{2, 0}, {0, 0.25}},
  InitializationCell->True,
  CellFrameMargins->8,
  CellFrameColor->RGBColor[0.592157, 0.313726, 0.313726],
  CellFrameLabels->{{Inherited, Inherited}, {None, Inherited}},
  Background->RGBColor[1, 1, 0.840558]],

Cell[BoxData[
    \(TraditionalForm\`\(Plot[Evaluate[result], {t, 0, tmax}, 
        PlotStyle \[Rule] Hue /@ {0,  .7}];\)\)], "Input",
  CellFrame->{{2, 0}, {0, 0.25}},
  InitializationCell->True,
  CellFrameMargins->8,
  CellFrameColor->RGBColor[0.592157, 0.313726, 0.313726],
  CellFrameLabels->{{Inherited, Inherited}, {None, Inherited}},
  Background->RGBColor[1, 1, 0.840558]],

Cell[TextData[{
  "For comparison, the following computes the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] t \[LessEqual] 4\)]],
  " without overshoot correction:"
}], "Text"],

Cell[BoxData[{
    \(TraditionalForm\`\(tmax = 4;\)\), "\n", 
    \(TraditionalForm\`RestartingNDSolve[\ 
      sys1, {x, y}, {t, 0, tmax}, {restartcond, restartfn}, 
      Reporting \[Rule] True, TimePrecisionGoal \[Rule] 0]\)}], "Input",
  CellFrame->{{2, 0}, {0, 0.25}},
  InitializationCell->True,
  CellFrameMargins->8,
  CellFrameColor->RGBColor[0.592157, 0.313726, 0.313726],
  CellFrameLabels->{{Inherited, Inherited}, {None, Inherited}},
  Background->RGBColor[1, 1, 0.840558]]
}, Closed]],

Cell[CellGroupData[{

Cell["The Budding Yeast Model", "SubsectionIcon"],

Cell[TextData[{
  "This simple model of the budding yeast cell cycle, proposed by Tyson and \
Nov\[AAcute]k [1], assumes a two-stage process. The first stage is the growth \
stage. Once certain molecular signals occur, the cell enters the ",
  StyleBox["mitosis",
    FontSlant->"Italic"],
  " phase in which chromosomes are duplicated and the cell splits in half. \
The molecular signals come from three proteins, whose concentrations\
\[LongDash]together with the mass of the yeast cell\[LongDash]comprise the \
components of the model. These are summarized below."
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          FormBox[
            StyleBox[
              FormBox[\(m(t)\),
                "TraditionalForm"],
              FontFamily->"Times"],
            "TraditionalForm"], 
          StyleBox[\(cell\ mass\),
            FontFamily->"Times"]},
        {
          FormBox[
            StyleBox[
              FormBox[\(\[CurlyPhi](t)\),
                "TraditionalForm"],
              FontFamily->"Times"],
            "TraditionalForm"], 
          StyleBox[\(total\ concentration\ of\ active\ cyclin/Cdk\ dimer\),
            FontFamily->"Times"]},
        {
          StyleBox[
            FormBox[\(\[Psi](t)\),
              "TraditionalForm"],
            FontFamily->"Times"], 
          StyleBox[\(relative\ concentration\ of\ active\ Cdh1/APC\),
            FontFamily->"Times"]},
        {
          StyleBox[
            FormBox[\(a(t)\),
              "TraditionalForm"],
            FontFamily->"Times"], 
          
          StyleBox[\(concentration\ of\ the\ APC\ activator\ protein\ \
\((Cdc14)\)\),
            FontFamily->"Times"]}
        },
      ColumnSpacings->1.5,
      ColumnWidths->{5, Automatic},
      ColumnAlignments->{Right, Left},
      ColumnsEqual->False]]]], "DefinitionBox",
  FontFamily->"Times"],

Cell[TextData[{
  "Cell splitting occurs when the concentration of the active cyclin/Cdk \
dimer reaches a sufficiently low level;",
  StyleBox[" i.e.",
    FontSlant->"Italic"],
  ", when ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyPhi](t)\)]],
  " drops below some threshold ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[CurlyPhi]\_\[Star]\),
          ScriptSizeMultipliers->0.87], TraditionalForm]]],
  ". At that time, the mass ",
  Cell[BoxData[
      \(TraditionalForm\`m(t)\)]],
  " is halved."
}], "Text"],

Cell["\<\
The model gives rise to the following system of differential \
equations.\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"eqns", ":=", 
        RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{
              FractionBox[\(\[PartialD]\(m(t)\)\), \(\[PartialD]t\),
                MultilineFunction->None], 
              "\[Equal]", \(\[Mu]\ \(m(t)\)\ \((1 - \(m(t)\)/M)\)\)}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
              
              FractionBox[\(\[PartialD]\(\[CurlyPhi](t)\)\), \(\[PartialD]t\),
                
                MultilineFunction->None], 
              "\[Equal]", \(k\_10 - \((k\_21 + \(k\_22\) \(\[Psi](
                          t)\))\)\ \(\[CurlyPhi](t)\)\)}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
              FractionBox[\(\[PartialD]\(\[Psi](t)\)\), \(\[PartialD]t\),
                MultilineFunction->None], 
              "\[Equal]", \(\(\((k\_31 + \(k\_32\) \(a(t)\))\)\ \((1 - \
\[Psi](t))\)\)\/\(J\_3 + 1 - \[Psi](t)\) - \(k\_4\) \(\(\ \)\(\(m(t)\)\ \(\
\[CurlyPhi](t)\)\ \(\[Psi](t)\)\)\)\/\(J\_4 + \[Psi](t)\)\)}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
              FractionBox[\(\[PartialD]\(a(t)\)\), \(\[PartialD]t\),
                MultilineFunction->None], 
              "\[Equal]", \(k\_51 + \(k\_52\) \(\(\ \)\(\((\(m(t)\)\ \(\
\[CurlyPhi](t)\))\)\^n\)\)\/\(J\_5\%n + \((\(m(t)\)\ \(\[CurlyPhi](t)\))\)\^n\
\) - k\_6\ \(a(t)\)\)}]}], "  ", "}"}]}], TraditionalForm]], "Input",
  CellFrame->{{2, 0}, {0, 0.25}},
  InitializationCell->True,
  CellFrameMargins->8,
  CellFrameColor->RGBColor[0.592157, 0.313726, 0.313726],
  CellFrameLabels->{{Inherited, Inherited}, {None, Inherited}},
  Background->RGBColor[1, 1, 0.840558]],

Cell["\<\
The following parameter values and initial values are similar to \
those suggested in [1]. (Time units are minutes.)\
\>", "Text"],

Cell[BoxData[{
    FormBox[\(\[Mu] = 0.01; \ M = 2;\), TraditionalForm], "\n", 
    FormBox[\(k\_10 = 0.04; \ k\_21 = 0.04; \ k\_22 = 1;\), 
      TraditionalForm], "\n", 
    FormBox[\(k\_31 = 1; \ k\_32 = 10; \ k\_4 = 35; \ J\_3 = 0.04; \ 
      J\_4 = 0.04;\), TraditionalForm], "\n", 
    FormBox[\(k\_51 = 0.005; \ k\_52 = 0.2; \ k\_6 = 0.1; \ n = 4; \ 
      J\_5 = 0.3;\), TraditionalForm], "\n", 
    FormBox[
      FormBox[\(inits = {m(0) \[Equal]  .6, \ \[CurlyPhi](
                  0) \[Equal]  .05, \ \[Psi](0) \[Equal]  .98, \ 
              a(0) \[Equal]  .4};\),
        "TraditionalForm"], TraditionalForm]}], "Input",
  CellFrame->{{2, 0}, {0, 0.25}},
  InitializationCell->True,
  CellFrameMargins->8,
  CellFrameColor->RGBColor[0.592157, 0.313726, 0.313726],
  CellFrameLabels->{{Inherited, Inherited}, {None, Inherited}},
  Background->RGBColor[1, 1, 0.840558]],

Cell[TextData[{
  "We can now use ",
  StyleBox["RestartingNDSolve",
    FontFamily->"Courier"],
  " to compute the solution. Note that the restart condition is ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyPhi](t) < 0.05\)]],
  " ",
  StyleBox["and",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CurlyPhi]\^\[Prime]\)(t) < 0\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(TraditionalForm\`\(tmax = 200;\)\), "\n", 
    \(TraditionalForm\`result = 
      RestartingNDSolve[\ 
        Join[eqns, inits], \ {\ m, \[CurlyPhi], \[Psi], a}, \ {\ t, 0, 
          tmax}, {\[CurlyPhi](t) \[LessEqual] 0.05 \[And] 
            k\_10 - \((k\_21 + k\_22\ \(\[Psi](t)\))\)\ \(\[CurlyPhi](t)\) < 
              0, \ \ { .5, 1, 1, 1} # &}, \ MinRecoveryTime \[Rule] 30, \ 
        Reporting \[Rule] True\ ]\)}], "Input",
  CellFrame->{{2, 0}, {0, 0.25}},
  InitializationCell->True,
  CellFrameMargins->8,
  CellFrameColor->RGBColor[0.592157, 0.313726, 0.313726],
  CellFrameLabels->{{Inherited, Inherited}, {None, Inherited}},
  Background->RGBColor[1, 1, 0.840558]],

Cell["\<\
Finally, here\[CloseCurlyQuote]s a plot of the solution:\
\>", \
"Text"],

Cell[BoxData[{
    \(TraditionalForm\`Needs["\<Graphics`Colors`\>"]; \ 
    Needs["\<Graphics`Legend`\>"];\), "\n", 
    \(TraditionalForm\`\(Plot[Evaluate[result], \ {t, 0, tmax}, \ 
        PlotStyle \[Rule] {Red, SeaGreen, MediumBlue, DeepCobaltViolet}, \ 
        PlotLegend \[Rule] {"\<mass\>", "\<cyclin/Cdk\>", "\<Cdh1/APC\>", \
"\<activator\>"}, \ LegendPosition \[Rule] {1.1, 0}, \ 
        LegendSize \[Rule] { .75,  .5}, ImageSize \[Rule] 500];\)\)}], "Input",\

  CellFrame->{{2, 0}, {0, 0.25}},
  InitializationCell->True,
  CellFrameMargins->8,
  CellFrameColor->RGBColor[0.592157, 0.313726, 0.313726],
  CellFrameLabels->{{Inherited, Inherited}, {None, Inherited}},
  Background->RGBColor[1, 1, 0.840558]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "SubsectionIcon"],

Cell[TextData[{
  "C. Fall, E. Marland, J. Wagner, and J. Tyson, ",
  StyleBox["Computational Cell Biology",
    FontSlant->"Italic"],
  ", Springer-Verlag, New York (2002)."
}], "Text",
  CellDingbat->"[1]"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Macintosh",
ScreenRectangle->{{0, 1639}, {0, 1028}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{749, 785},
WindowMargins->{{152, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3305099142-2784705"->{
    Cell[4888, 160, 412, 7, 55, "Print",
      CellTags->"Info3305099142-2784705"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3305099142-2784705", 29112, 898}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 169, 3, 72, "Subtitle"],
Cell[1948, 58, 444, 13, 21, "Text"],

Cell[CellGroupData[{
Cell[2417, 75, 40, 0, 21, "SubsubsectionIcon"],
Cell[2460, 77, 367, 11, 84, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2864, 93, 37, 0, 25, "SubsectionIcon"],
Cell[2904, 95, 492, 11, 47, "Text"],
Cell[3399, 108, 481, 17, 34, "Text"],
Cell[3883, 127, 708, 21, 47, "Text"],

Cell[CellGroupData[{
Cell[4616, 152, 269, 6, 41, "Input"],
Cell[4888, 160, 412, 7, 55, "Print",
  CellTags->"Info3305099142-2784705"]
}, Open  ]],
Cell[5315, 170, 128, 5, 21, "Text"],
Cell[5446, 177, 1102, 32, 39, "DefinitionBox"],
Cell[6551, 211, 132, 5, 21, "Text"],
Cell[6686, 218, 104, 5, 21, "Text"],
Cell[6793, 225, 135, 5, 21, "Text"],
Cell[6931, 232, 227, 10, 21, "Text"],
Cell[7161, 244, 47, 0, 21, "Text"],
Cell[7211, 246, 158, 5, 42, "Text"],

Cell[CellGroupData[{
Cell[7394, 255, 49, 0, 21, "SubsubsectionIcon"],
Cell[7446, 257, 1411, 38, 73, "Text"],
Cell[8860, 297, 118, 3, 21, "Text"],
Cell[8981, 302, 932, 27, 69, "DefinitionBox3Col"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9950, 334, 42, 0, 21, "SubsubsectionIcon"],
Cell[9995, 336, 1076, 30, 74, "DefinitionBox3Col"],
Cell[11074, 368, 652, 17, 60, "Text"],
Cell[11729, 387, 204, 6, 21, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11970, 398, 35, 0, 21, "SubsubsectionIcon"],
Cell[12008, 400, 147, 5, 21, "Text"],
Cell[12158, 407, 3568, 101, 44, "Program",
  Evaluatable->False],
Cell[15729, 510, 308, 9, 21, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16074, 524, 48, 0, 21, "SubsubsectionIcon"],
Cell[16125, 526, 316, 7, 41, "Input",
  InitializationCell->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[16490, 539, 42, 0, 25, "SubsectionIcon"],
Cell[16535, 541, 266, 7, 21, "Text"],
Cell[16804, 550, 884, 22, 60, "Input",
  InitializationCell->True],
Cell[17691, 574, 481, 12, 34, "Text"],
Cell[18175, 588, 890, 24, 56, "Input",
  InitializationCell->True],
Cell[19068, 614, 170, 5, 21, "Text"],
Cell[19241, 621, 477, 11, 56, "Input",
  InitializationCell->True],
Cell[19721, 634, 382, 8, 41, "Input",
  InitializationCell->True],
Cell[20106, 644, 202, 5, 21, "Text"],
Cell[20311, 651, 486, 10, 56, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[20834, 666, 49, 0, 25, "SubsectionIcon"],
Cell[20886, 668, 579, 10, 60, "Text"],
Cell[21468, 680, 1287, 40, 93, "DefinitionBox"],
Cell[22758, 722, 530, 17, 34, "Text"],
Cell[23291, 741, 97, 3, 21, "Text"],
Cell[23391, 746, 1702, 36, 193, "Input",
  InitializationCell->True],
Cell[25096, 784, 140, 3, 21, "Text"],
Cell[25239, 789, 883, 18, 101, "Input",
  InitializationCell->True],
Cell[26125, 809, 386, 14, 21, "Text"],
Cell[26514, 825, 702, 14, 71, "Input",
  InitializationCell->True],
Cell[27219, 841, 82, 3, 21, "Text"],
Cell[27304, 846, 720, 14, 86, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[28061, 865, 36, 0, 25, "SubsectionIcon"],
Cell[28100, 867, 208, 6, 21, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

